@@ -17,16 +17,20 @@ class MemoryUnit(Enum):
 
 
 class Memory(long):
+    # noinspection PyInitNewSignature
     def __new__(cls, x, unit=None):
         if isinstance(x, str):
             units_regex = '|'.join(MemoryUnit.__members__.keys())
             m = match(r'^(\d+) ?({})$'.format(units_regex), x)
             if m is None:
-                raise ValueError('{} requires am integer or a string in the format "<value> ({})"'.format(
-                    Memory.__class__.__name__, units_regex))
+                raise ValueError(
+                    '{} requires am integer or a string in the format "<value>'
+                    ' ({})"'.format(Memory.__class__.__name__, units_regex)
+                )
             x = int(m.group(1)) * MemoryUnit.__members__.get(m.group(2)).value
         elif unit is None:
             raise ValueError('No unit provided.')
         else:
             x = x * unit.value
+        # noinspection PyTypeChecker
         return super(Memory, cls).__new__(cls, x)
